import { Rule } from "eslint";
interface RelativePathConfig {
    /**
     * The starting path from which a relative depth is accepted.
     *
     * @example
     * With a configuration like `{ path: "src/foo", depth: 0 }`
     *      1. Relative paths can be used in `./src/foo`.
     *      2. Relative paths can be used in `./src/foo/bar`.
     *      3. Relative paths can NOT be used in `./src`.
     *
     * @example
     * With a configuration like `{ path: "src", depth: 0 }`
     *      1. Relative paths can be used in `./src/foo`.
     *      2. Relative paths can be used in `./src/bar/baz`.
     *      3. Relative paths can be used in `./src`.
     */
    path: string;
    /**
     * A positive number which represents the relative depth
     * that is acceptable for the associated path.
     *
     * @example
     * In `./src/foo` with `path: "src"`
     *      1. `import "./bar"` for `./src/bar` when `depth` \>= `0`.
     *      2. `import "./bar/baz"` when `depth` \>= `0`.
     *      3. `import "../bar"` when `depth` \>= `1`.
     */
    depth: number;
}
interface RelativeGlobConfig {
    /**
     * A regex string pattern that is used to match the file path.
     *
     * @example
     * With a configuration like `{ pattern: "index.ts", depth: 0 }`
     *      1. Relative paths can be used in files such as `./src/index.ts`.
     *      1. Relative paths can be used any file in the folder `./src/index.ts/*`.
     *      2. Relative paths can NOT be used in files such as `./src/foo.ts`.
     *
     * @example
     * With a configuration like `{ pattern: "index\\.(ts|js)$" depth: 0 }`
     *      1. Relative paths can be used in any file that ends with `index.js` or `index.ts`.
     *      1. Relative paths can be NOT in the folder `./src/index.ts/*`.
     *      2. Relative paths can be NOT used in `./src/foo.ts`.
     */
    pattern: string;
    /**
     * A positive number which represents the relative depth
     * that is acceptable for the associated path.
     *
     * @example
     * In `./src/foo.ts` with `pattern: "foo.ts$"`
     *      1. `import "./bar"` for `./src/bar` when `depth` \>= `0`.
     *      2. `import "./bar/baz"` when `depth` \>= `0`.
     *      3. `import "../bar"` when `depth` \>= `1`.
     */
    depth: number;
}
type RelativeImportConfig = RelativePathConfig | RelativeGlobConfig;
export type ImportAliasOptions = {
    aliasConfigPath?: string;
    aliasImportFunctions: string[];
    /** An array defining which paths can be allowed to used relative imports within it to defined depths. */
    relativeImportOverrides?: RelativeImportConfig[];
    isAllowBaseUrlResolvedImport: boolean;
};
declare const importAliasRule: Rule.RuleModule;
export { importAliasRule };
